@@ -1,7 +1,8 @@
 from django.urls import path
 from django.utils.html import format_html
+from wagtail import hooks
 from wagtail.admin.staticfiles import versioned_static
-from wagtail.core import hooks
+
 from .views import get_image_rendition
 
 
@@ -18,7 +19,8 @@ def global_admin_css():
 def global_admin_js():
     """Add /static/css/custom.js to the admin."""
     return format_html(
-        '<script src="{}"></script>', versioned_static("wagtail_meta_preview/wagtail-meta-preview.js"),
+        '<script src="{}"></script>',
+        versioned_static("wagtail_meta_preview/wagtail-meta-preview.js"),
     )
 
 
